@@ -6,12 +6,12 @@
     <message>
         <location filename="../mainwindow.ui" line="14"/>
         <source>Program_Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Program_Name</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="46"/>
         <source>Quit application</source>
-        <translation>Zamknij apliikację</translation>
+        <translation>Zakończ aplikację</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="49"/>
@@ -68,82 +68,82 @@
         <location filename="../mainwindow.cpp" line="484"/>
         <location filename="../mainwindow.cpp" line="502"/>
         <source>Select ISO</source>
-        <translation type="unfinished"></translation>
+        <translation>Wybierz ISO</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="250"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Wybierz docelowe urządzenie USB&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="260"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Wybierz plik ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="289"/>
         <source>Advanced Options</source>
-        <translation type="unfinished"></translation>
+        <translation>Zaawansowane opcje</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="298"/>
         <source>Verbosity (less to more):</source>
-        <translation type="unfinished"></translation>
+        <translation>Szczegółowość (mniej oznacza większą):</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="349"/>
         <source>Size of ESP (uefi) partition:</source>
-        <translation type="unfinished"></translation>
+        <translation>Rozmiar partycji ESP (uefi):</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="381"/>
         <source>Make the ext4 filesystem even if one exists</source>
-        <translation type="unfinished"></translation>
+        <translation>Utwórz system plików ext4, nawet jeśli taki istnieje</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="388"/>
         <source>Save the original boot directory when updating a live-usb</source>
-        <translation type="unfinished"></translation>
+        <translation>Zapisz oryginalny katalog rozruchowy podczas aktualizacji live-usb</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="395"/>
         <source>Use gpt partitioning instead of msdos</source>
-        <translation type="unfinished"></translation>
+        <translation>Użyj partycjonowania gpt zamiast msdos</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="398"/>
         <source>GPT partitioning</source>
-        <translation type="unfinished"></translation>
+        <translation>Partycjonowanie GPT</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="405"/>
         <source>Update (only update an existing live-usb)</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktualizuj (aktualizuj tylko istniejący live-usb)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="412"/>
         <source>Don&apos;t replace syslinux files</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie zastępuj plików syslinux</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="415"/>
         <source>Keep syslinux files</source>
-        <translation type="unfinished"></translation>
+        <translation>Zachowaj pliki syslinux</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="422"/>
         <source>Ignore USB/removable check</source>
-        <translation type="unfinished"></translation>
+        <translation>Zignoruj sprawdzanie USB/pamięci przenośnej</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="429"/>
         <source>Temporarily disable automounting</source>
-        <translation type="unfinished"></translation>
+        <translation>Tymczasowo wyłącz automontowanie</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="439"/>
         <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
-        <translation type="unfinished"></translation>
+        <translation>Ustaw flagę dysku pmbr_boot (nie uruchomi się przez UEFI)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="446"/>
@@ -153,38 +153,38 @@
     <message>
         <location filename="../mainwindow.ui" line="459"/>
         <source>Refresh drive list</source>
-        <translation type="unfinished"></translation>
+        <translation>Odśwież listę napędów</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="473"/>
         <location filename="../mainwindow.cpp" line="430"/>
         <source>Show advanced options</source>
-        <translation type="unfinished"></translation>
+        <translation>Pokaż opcje zaawansowane</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="493"/>
         <source>Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Tryb</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="508"/>
         <source>Full-featured mode - writable LiveUSB</source>
-        <translation type="unfinished"></translation>
+        <translation>W pełni funkcjonalny - zapisywalny LiveUSB</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="518"/>
         <source>Read-only, cannot be used with persistency</source>
-        <translation type="unfinished"></translation>
+        <translation>Tylko do odczytu, nie można zapisywać danych korzystając z Persistence</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="521"/>
         <source>Image mode - read-only LiveUSB (dd)</source>
-        <translation type="unfinished"></translation>
+        <translation>Tryb obrazu - LiveUSB tylko do odczytu (dd)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="535"/>
         <source>For distros other than antiX/MX use image mode (dd).</source>
-        <translation type="unfinished"></translation>
+        <translation>Dla dystrybucji innych niż antiX/MX, użyj trybu obrazu (dd).</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="583"/>
@@ -194,66 +194,68 @@
     <message>
         <location filename="../mainwindow.ui" line="618"/>
         <source>Percent of USB-device to use:</source>
-        <translation type="unfinished"></translation>
+        <translation>Procent urządzenia USB do wykorzystania:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="625"/>
         <source>Label ext partition:</source>
-        <translation type="unfinished"></translation>
+        <translation>Etykieta partycji ext:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="673"/>
         <source>Don&apos;t run commands that affect the usb device</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie uruchamiaj poleceń, które wpływają na urządzenie USB</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="676"/>
         <source>Dry run (no change to system)</source>
-        <translation type="unfinished"></translation>
+        <translation>Przebieg próbny (bez zmian w systemie)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="683"/>
         <source>clone from a mounted live-usb or iso-file.</source>
-        <translation type="unfinished"></translation>
+        <translation>klonuj z zamontowanego live-usb lub pliku iso.</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="686"/>
         <source>Clone an existing live system</source>
-        <translation type="unfinished"></translation>
+        <translation>Klonuj istniejący system live</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="693"/>
         <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
-        <translation type="unfinished"></translation>
+        <translation>Ustawienie rozruchu z zaszyfrowanej partycji spowoduje wyświetlenie prośby o podanie hasła przy pierwszym uruchomieniu</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="696"/>
         <source>Encrypt</source>
-        <translation type="unfinished"></translation>
+        <translation>Szyfruj</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="703"/>
         <source>Clone running live system</source>
-        <translation type="unfinished"></translation>
+        <translation>Klonuj uruchomiony system live</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="78"/>
         <location filename="../mainwindow.cpp" line="252"/>
         <location filename="../mainwindow.cpp" line="415"/>
         <source>Failure</source>
-        <translation type="unfinished"></translation>
+        <translation>Niepowodzenie</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="78"/>
         <source>Source and destination are on the same device, please select again.</source>
-        <translation type="unfinished"></translation>
+        <translation>Źródło i miejsce docelowe znajdują się na tym samym urządzeniu, proszę wybierz ponownie.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="103"/>
         <source>Writing %1 using &apos;dd&apos; command to /dev/%2,
 
 Please wait until the the process is completed</source>
-        <translation type="unfinished"></translation>
+        <translation>Zapisywanie %1 przy użyciu polecenia &quot;dd&quot; do /dev/%2,
+
+Poczekaj, aż proces się zakończy.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="250"/>
@@ -263,12 +265,12 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../mainwindow.cpp" line="250"/>
         <source>LiveUSB creation successful!</source>
-        <translation type="unfinished"></translation>
+        <translation>Tworzenie LiveUSB zakończyło się sukcesem!</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="252"/>
         <source>Error encountered in the LiveUSB creation process</source>
-        <translation type="unfinished"></translation>
+        <translation>Wystąpił błąd podczas tworzenia LiveUSB.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="298"/>
@@ -278,13 +280,13 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../mainwindow.cpp" line="298"/>
         <source>Please select a USB device to write to</source>
-        <translation type="unfinished"></translation>
+        <translation>Wybierz urządzenie USB, którego chcesz użyć do zapisu</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="301"/>
         <location filename="../mainwindow.cpp" line="496"/>
         <source>clone</source>
-        <translation type="unfinished"></translation>
+        <translation>klonuj</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="340"/>
@@ -299,12 +301,12 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../mainwindow.cpp" line="342"/>
         <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
-        <translation type="unfinished"></translation>
+        <translation>Program do tworzenia live-usb z pliku iso, z innego live-usb, z live-cd/dvd lub z uruchomionego systemu live.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="344"/>
         <source>Copyright (c) MX Linux</source>
-        <translation>Copyright (c) MX Linux</translation>
+        <translation>Prawa autorskie © MX Linux</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="345"/>
@@ -330,35 +332,35 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../mainwindow.cpp" line="404"/>
         <source>Select an ISO file to write to the USB drive</source>
-        <translation type="unfinished"></translation>
+        <translation>Wybierz plik ISO, który chcesz zapisać na dysku USB</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="410"/>
         <location filename="../mainwindow.cpp" line="480"/>
         <source>Select Source Directory</source>
-        <translation type="unfinished"></translation>
+        <translation>Wybierz katalog źródłowy</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="415"/>
         <source>Could not find %1/antiX/linuxfs file</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie można znaleźć pliku %1/antiX/linuxfs</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="436"/>
         <source>Hide advanced options</source>
-        <translation type="unfinished"></translation>
+        <translation>Ukryj opcje zaawansowane</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="479"/>
         <location filename="../mainwindow.cpp" line="494"/>
         <source>Select Source</source>
-        <translation type="unfinished"></translation>
+        <translation>Wybierz źródło</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="483"/>
         <location filename="../mainwindow.cpp" line="500"/>
         <source>Select ISO file</source>
-        <translation type="unfinished"></translation>
+        <translation>Wybierz plik ISO</translation>
     </message>
 </context>
 <context>
@@ -366,7 +368,7 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../main.cpp" line="66"/>
         <source>You must run this program as root.</source>
-        <translation>Musisz uruchomić ten program jako administrator. </translation>
+        <translation>Musisz uruchomić ten program jako administrator. </translation>
     </message>
 </context>
 </TS>
